@@ -1,19 +1,19 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "netbsd1.3.3"
+#define HOST_OS "netbsd1.4"
 #define HOST_OS_NAME "netbsd1"
-#define HOST_OS_VERSION "1.3.3"
+#define HOST_OS_VERSION "1.4"
 #define HOST_ARCH "i386"
-#define HOST_NAME "london"
+#define HOST_NAME "mayfly.mcl.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Tue Sep  7 16:52:12 PDT 1999"
+#define CONFIG_DATE "Tue Sep  7 22:51:19 PDT 1999"
 #define PACKAGE "am-utils"
 #define VERSION "6.0.1"
 #define PACKAGE "am-utils"
 #define VERSION "6.0.1"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "1.3.3"
+#define HOST_HEADER_VERSION "1.4"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
@@ -34,6 +34,9 @@
 #define HAVE_GETMNTINFO 1
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
+#define HAVE_HES_INIT 1
+#define HAVE_HESIOD_INIT 1
+#define HAVE_HESIOD_TO_BIND 1
 #define HAVE_MEMCMP 1
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
@@ -115,7 +118,9 @@
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_ARPA_NAMESER_H 1
 #define HAVE_ARPA_INET_H 1
+#define HAVE_ISOFS_CD9660_CD9660_MOUNT_H 1
 #define HAVE_MACHINE_ENDIAN_H 1
+#define HAVE_MSDOSFS_MSDOSFSMOUNT_H 1
 #define HAVE_NET_IF_H 1
 #define HAVE_NET_ROUTE_H 1
 #define HAVE_NETINET_IF_ETHER_H 1
@@ -162,10 +167,13 @@
 #define HAVE_ERRNO_H 1
 #define HAVE_FCNTL_H 1
 #define HAVE_GRP_H 1
+#define HAVE_HESIOD_H 1
+#define HAVE_LIBGEN_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_NDBM_H 1
 #define HAVE_NETDB_H 1
+#define HAVE_NSSWITCH_H 1
 #define HAVE_PWD_H 1
 #define HAVE_REGEX_H 1
 #define HAVE_RESOLV_H 1
@@ -182,7 +190,7 @@
 #define HAVE_UNISTD_H 1
 #define TIME_WITH_SYS_TIME 1
 #define HAVE_ST_RDEV 1
-#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_netbsd1_3.h"
+#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_netbsd1_4.h"
 #define HAVE_STRUCT_NFS_ARGS 1
 #define nfs_args_t struct nfs_args
 #define NFS_FH_FIELD fh
@@ -190,6 +198,7 @@
 #define am_nfs_fh3 nfs_fh3
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
+#define HAVE_FHANDLE 1
 #define MTYPE_TYPE char *
 #define MTYPE_PRINTF_TYPE "%s"
 #define YP_ORDER_OUTORDER_TYPE int
@@ -241,6 +250,7 @@
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
 #define HAVE_MAP_FILE 1
+#define HAVE_MAP_HESIOD 1
 #define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_PASSWD 1
